EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ContainerUsage_RecordContainers',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records the specified container data.'
GO

IF OBJECT_ID('[ContainerUsage_RecordContainers]') IS NOT NULL DROP PROCEDURE [ContainerUsage_RecordContainers]
GO

SET QUOTED_IDENTIFIER ON
GO

IF TYPE_ID('ContainerUsageEntry') IS NOT NULL DROP TYPE ContainerUsageEntry

CREATE TYPE ContainerUsageEntry AS TABLE
(
	[Server_Name] NVARCHAR(250) NOT NULL,
	[Container_Name] VARCHAR(200) NOT NULL,
	[Image_Id] VARCHAR(128) NOT NULL,
	[Details_Url] VARCHAR(256) NULL,
	[ContainerStatus_Code] VARCHAR(16) NOT NULL,
	[Created_Date] DATETIME NOT NULL
)
GO

GRANT EXECUTE ON TYPE::[ContainerUsageEntry] TO [ProGetUser_Role]
GO

CREATE PROCEDURE [ContainerUsage_RecordContainers]
(
	@PackageContainerScanner_Id INT,
	@ContainerUsageEntry_Table dbo.ContainerUsageEntry READONLY
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

	-- use CTE as filter to prevent full table scan
	;WITH Filtered_CU
	AS
	(
		SELECT *
		  FROM [ContainerUsage]
		 WHERE [PackageContainerScanner_Id] = @PackageContainerScanner_Id
	)
	MERGE Filtered_CU AS TARGET
	USING @ContainerUsageEntry_Table AS SOURCE
	   ON (
		       TARGET.[Server_Name] = SOURCE.[Server_Name]
		   AND TARGET.[Container_Name] = SOURCE.[Container_Name]
		  )

	 WHEN MATCHED THEN
		UPDATE SET TARGET.[Details_Url] = SOURCE.[Details_Url],
		           TARGET.[Image_Id] = SOURCE.[Image_Id],
				   TARGET.[ContainerStatus_Code] = SOURCE.[ContainerStatus_Code],
				   TARGET.[Updated_Date] = GETUTCDATE(),
				   TARGET.[Created_Date] = SOURCE.[Created_Date]

	 WHEN NOT MATCHED BY TARGET THEN
		INSERT
		(
			[PackageContainerScanner_Id],
			[Server_Name],
			[Container_Name],
			[Image_Id],
			[Details_Url],
			[ContainerStatus_Code],
			[Updated_Date],
			[Created_Date]
		)
		VALUES
		(
			@PackageContainerScanner_Id,
			SOURCE.[Server_Name],
			SOURCE.[Container_Name],
			SOURCE.[Image_Id],
			SOURCE.[Details_Url],
			SOURCE.[ContainerStatus_Code],
			GETUTCDATE(),
			SOURCE.[Created_Date]
		)

	 WHEN NOT MATCHED BY SOURCE THEN
		UPDATE SET TARGET.[ContainerStatus_Code] = 'Removed',
				   TARGET.[Updated_Date] = GETUTCDATE()
	;

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ContainerUsage_RecordContainers] TO [ProGetUser_Role]
GO