EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_GetPackageCount',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Package_Count',
    /* Description_Text        */ 'Returns the number of packages in the specified feed.'
GO

IF OBJECT_ID('[Feeds_GetPackageCount]') IS NOT NULL DROP PROCEDURE [Feeds_GetPackageCount]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_GetPackageCount]
(
	@Feed_Id INT,
	@IncludeAllVersions_Indicator YNINDICATOR,
	@IncludeCached_Indicator YNINDICATOR,
	@Package_Count INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

	IF @IncludeCached_Indicator = 'Y'
		IF @IncludeAllVersions_Indicator = 'Y'
			SELECT @Package_Count = [Version_Count]
			  FROM [DashboardFeeds]
			 WHERE [Feed_Id] = @Feed_Id
		ELSE
			SELECT @Package_Count = [Package_Count]
			  FROM [DashboardFeeds]
			 WHERE [Feed_Id] = @Feed_Id
	ELSE
		IF @IncludeAllVersions_Indicator = 'N'
			SELECT @Package_Count = COUNT(DISTINCT [Package_Id])
			  FROM [Packages_Combined]
			 WHERE [Feed_Id] = @Feed_Id
		ELSE
			SELECT @Package_Count = COUNT([Package_Id])
			  FROM [Packages_Combined]
			 WHERE [Feed_Id] = @Feed_Id

END
GO

GRANT EXECUTE ON [Feeds_GetPackageCount] TO [ProGetUser_Role]
GO
