EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'PypiPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records a PyPI package in the database.'
GO

IF OBJECT_ID('[PypiPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [PypiPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [PypiPackages_CreateOrUpdatePackage]
(
	@Feed_Id INT,
	@Package_Name VARCHAR(200),
	@Version_Text VARCHAR(200),
	@File_Name VARCHAR(200),
	@Cached_Indicator YNINDICATOR,
	@Published_Date DATETIME,
	@Package_Size BIGINT,
	@Summary_Text NVARCHAR(500),
	@MD5Hash_Bytes VARBINARY(16),
	@SHA1Hash_Bytes VARBINARY(20),
	@SHA256Hash_Bytes VARBINARY(32),
	@SHA512Hash_Bytes VARBINARY(64),
	@PackageMetadata_Bytes VARBINARY(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [PypiPackages] WHERE [Feed_Id] = @Feed_Id AND [Package_Name] = @Package_Name AND [Version_Text] = @Version_Text AND [File_Name] = @File_Name)
	BEGIN

		UPDATE [PypiPackages]
		   SET [Cached_Indicator] = @Cached_Indicator,
			   [Published_Date] = @Published_Date,
			   [Package_Size] = @Package_Size,
			   [Summary_Text] = @Summary_Text,
			   [MD5Hash_Bytes] = @MD5Hash_Bytes,
			   [SHA1Hash_Bytes] = @SHA1Hash_Bytes,
			   [SHA256Hash_Bytes] = @SHA256Hash_Bytes,
			   [SHA512Hash_Bytes] = @SHA512Hash_Bytes,
			   [PackageMetadata_Bytes] = @PackageMetadata_Bytes
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Package_Name] = @Package_Name
		   AND [Version_Text] = @Version_Text
		   AND [File_Name] = @File_Name

		EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @Package_Name, 'Package_Version', @Version_Text

	END
	ELSE
	BEGIN

		INSERT INTO [PypiPackages]
		(
			[Feed_Id],
			[Package_Name],
			[Version_Text],
			[File_Name],
			[Cached_Indicator],
			[Published_Date],
			[Package_Size],
			[Summary_Text],
			[MD5Hash_Bytes],
			[SHA1Hash_Bytes],
			[SHA256Hash_Bytes],
			[SHA512Hash_Bytes],
			[Download_Count],
			[PackageMetadata_Bytes]
		)
		VALUES
		(
			@Feed_Id,
			@Package_Name,
			@Version_Text,
			@File_Name,
			@Cached_Indicator,
			@Published_Date,
			@Package_Size,
			@Summary_Text,
			@MD5Hash_Bytes,
			@SHA1Hash_Bytes,
			@SHA256Hash_Bytes,
			@SHA512Hash_Bytes,
			0,
			@PackageMetadata_Bytes
		)

		EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Package_Name, 'Package_Version', @Version_Text

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [PypiPackages_CreateOrUpdatePackage] TO [ProGetUser_Role]
GO
