--AH:ScriptId=29bad54c-3154-49a1-a4d6-bcc3f3de48a1;3122
CREATE TABLE [VulnerabilitySources]
(
	[VulnerabilitySource_Id] INT IDENTITY(1, 1) NOT NULL,
	[VulnerabilitySource_Name] VARCHAR(50) NOT NULL,
	[Configuration_Xml] XML NOT NULL,

	CONSTRAINT [PK__VulnerabilitySources]
		PRIMARY KEY ([VulnerabilitySource_Id])
)

CREATE TABLE [AssessmentTypes]
(
	[AssessmentType_Id] INT IDENTITY(1, 1) NOT NULL,
	[AssessmentType_Name] NVARCHAR(200) NOT NULL,
	[BlockDownload_Indicator] YNINDICATOR NOT NULL,
	[Expiration_Days] INT NULL,
	[Severity_Code] CHAR(1) NOT NULL,
	[Custom_Color] INT NULL,

	CONSTRAINT [PK__AssessmentTypes]
		PRIMARY KEY ([AssessmentType_Id]),

	CONSTRAINT [CK__AssessmentTypes__Expiration_Days]
		CHECK ([Expiration_Days] IS NULL OR [Expiration_Days] > 0),

	CONSTRAINT [CK__AssessmentTypes__Severity_Code]
		CHECK ([Severity_Code] IN ('N', 'W', 'E', 'C')),

	CONSTRAINT [CK__AssessmentTypes__Custom_Color]
		CHECK (([Severity_Code] = 'C' AND [Custom_Color] IS NOT NULL) OR ([Severity_Code] <> 'C' AND [Custom_Color] IS NULL))
)

CREATE TABLE [Vulnerabilities]
(
	[Vulnerability_Id] INT IDENTITY(1, 1) NOT NULL,
	[FeedType_Name] VARCHAR(20) NOT NULL,
	[External_Id] VARCHAR(100) NULL,
	[Package_Name] VARCHAR(200) NOT NULL,
	[Package_Versions] VARCHAR(200) NOT NULL,
	[Title_Text] NVARCHAR(200) NOT NULL,
	[Description_Text] NVARCHAR(MAX) NOT NULL,
	[VulnerabilitySource_Id] INT NOT NULL,

	[AssessmentType_Id] INT NULL,
	[Assessment_Date] DATETIME NULL,
	[AssessedBy_User_Name] USERNAME NULL,

	CONSTRAINT [PK__Vulnerabilities]
		PRIMARY KEY ([Vulnerability_Id]),

	CONSTRAINT [FK__Vulnerabilities__VulnerabilitySources]
		FOREIGN KEY ([VulnerabilitySource_Id])
		REFERENCES [VulnerabilitySources] ([VulnerabilitySource_Id])
		ON DELETE CASCADE,

	CONSTRAINT [FK__Assessments__AssessmentTypes]
		FOREIGN KEY ([AssessmentType_Id])
		REFERENCES [AssessmentTypes] ([AssessmentType_Id])
		ON DELETE SET NULL
)

CREATE NONCLUSTERED INDEX [IX__Vulnerabilities__Packages]
	ON [Vulnerabilities] ([VulnerabilitySource_Id], [FeedType_Name], [Package_Name])

CREATE TABLE [VulnerabilityComments]
(
	[VulnerabilityComment_Id] INT IDENTITY(1, 1) NOT NULL,
	[Vulnerability_Id] INT NOT NULL,
	[Comment_Text] NVARCHAR(MAX) NOT NULL,
	[CommentedBy_User_Name] USERNAME NOT NULL,
	[CommentedOn_Date] DATETIME NOT NULL,

	CONSTRAINT [PK_VulnerabilityComments]
		PRIMARY KEY ([VulnerabilityComment_Id]),

	CONSTRAINT [FK__VulnerabilityComments__Vulnerabilities]
		FOREIGN KEY ([Vulnerability_Id])
		REFERENCES [Vulnerabilities] ([Vulnerability_Id])
		ON DELETE CASCADE
)

CREATE NONCLUSTERED INDEX [IX__VulnerabilityComments__Vulnerabilities]
	ON [VulnerabilityComments] ([Vulnerability_Id])

CREATE TABLE [FeedVulnerabilitySources]
(
	[Feed_Id] INT NOT NULL,
	[VulnerabilitySource_Id] INT NOT NULL,

	CONSTRAINT [PK__FeedVulnerabilitySources]
		PRIMARY KEY ([Feed_Id], [VulnerabilitySource_Id]),

	CONSTRAINT [FK__FeedVulnerabilitySources__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE,

	CONSTRAINT [FK__FeedVulnerabilitySources__VulnerabilitySources]
		FOREIGN KEY ([VulnerabilitySource_Id])
		REFERENCES [VulnerabilitySources] ([VulnerabilitySource_Id])
		ON DELETE CASCADE
)